// Function for getting all issues
// params 
// url = Bugify server URL 
// api = Users Bugify API Key

function getIssues(url,api,type) {
		
	$('.loading-data').css('display','inline');
	
	// Submit the request using AJAX.
	$.ajax({
	    type: 'GET',
	    url: url+'/api/issues/'+type+'.json?api_key='+api,
	    dataType: 'json'
	})
	
	// If the request is successfull...
	.done(function(response) {
		
		// Empty any current bugs from the bug lists
		$('.issues-list').empty();
	
		// Beginning variables for the High, Normal and Low priority issues totals
		var hcount = 0;
		var mcount = 0;
		var lcount = 0;
		
		function issueTemplate(i) {
			
			var body  =    '<div class="issue-box">';
				body +=	   '<span class="state-'+response.issues[i].state+'">'+response.issues[i].state_name+'</span>';
				body +=	   '<b>Issue #'+response.issues[i].id+' - '+response.issues[i].subject+'</b>';
				body +=	   '<p>'+response.issues[i].description+'</p>';
				body +=    '<div class="button-box">';
				body +=    '<button type="button" class="issue-details button" data-issue-id="'+response.issues[i].id+'">Details</button>';
				body +=    '<button type="button" class="issue-comments button" data-issue-id="'+response.issues[i].id+'">Comments</button>';
				body +=    '</div>';
				body +=	   '</div>';
				
			return body;
		}
		
		// For each High Priority issue (2), add them to the High Priority list
		$(response.issues).each(function(h){
			if (response.issues[h].priority == 2) {
			$('.high-priority-issues').append(issueTemplate(h));
			// Increment the High Priority Count
			hcount++;
			}
		});
		
		// For each Normal Priority issue (1), add them to the Normal Priority list
		$(response.issues).each(function(m){
			if (response.issues[m].priority == 1) {
			$('.med-priority-issues').append(issueTemplate(m));
			// Increment the Normal Priority Count
			mcount++;
			}
		});
		
		// For each Low Priority issue (0), add them to the Low Priority list
		$(response.issues).each(function(l){
			if (response.issues[l].priority == 0) {
			$('.low-priority-issues').append(issueTemplate(l));
			// Increment the Low Priority Count
			lcount++;
			}
		});
		
		// Display the totals in the badges next to each list title
		$('.high-priority-total').text(hcount);
		$('.med-priority-total').text(mcount);
		$('.low-priority-total').text(lcount);
		
		// Hide the loading gif
		$('.failed-attempt').remove();
		$('.loading-data').hide();
	})
	
	// If the request fails, show a failure message in the lists
	.fail(function(data) {
		
		$('.failed-attempt').remove();
	    $('main').append('<p class="failed-attempt">Failed to retreive records. Check your settings and internet connection.</p>');
	    $('.loading-data').hide();
	});
}

function getIssueDetails(url,id,api) {
		
	$('.loading-data').css('display','inline');
	$('.action-panel').hide().empty();
	
	// Submit the form using AJAX.
	$.ajax({
	    type: 'GET',
	    url: url+'/api/issues/'+id+'.json?api_key='+api,
	    dataType: 'json'
	})
	
	.done(function(response) {
		
		function detailsTemplate() {
			
			var body  = '<p><b>Details for issue #'+response.issues[0].id+'</b></p>';
				body += '<form method="POST" class="issue-details-form" action="'+url+'/api/issues/'+response.issues[0].id+'.json?api_key='+api+'" data-issues-id="'+response.issues[0].id+'">';
				body += '<input type="hidden" name="method" value="update" id="issue-details-method">';
				body += '<label for="issue-details-priority">Priority</label>';
				body += '<select name="issue[priority]" id="issue-details-priority">';
				body +=	(response.issues[0].priority == 0) ? '<option value="0" selected>Low</option>'    : '<option value="0">Low</option>';
				body +=	(response.issues[0].priority == 1) ? '<option value="1" selected>Normal</option>' : '<option value="1">Normal</option>';
				body +=	(response.issues[0].priority == 2) ? '<option value="2" selected>High</option>'   : '<option value="2">High</option>';
				body +=	'</select>';
				body += '<label for="issue-details-state">State</label>';
				body += '<select name="issue[state]" id="issue-details-state">';
				body +=	(response.issues[0].state == 0) ? '<option value="0" selected>Open</option>'        : '<option value="0">Open</option>';
				body +=	(response.issues[0].state == 1) ? '<option value="1" selected>In Progress</option>' : '<option value="1">In Progress</option>';
				body +=	(response.issues[0].state == 2) ? '<option value="2" selected>Resolved</option>'    : '<option value="2">Resolved</option>';
				body +=	(response.issues[0].state == 3) ? '<option value="3" selected>Closed</option>'      : '<option value="3">Closed</option>';
				body +=	(response.issues[0].state == 4) ? '<option value="4" selected>Re-Opened</option>'   : '<option value="4">Re-Opened</option>';
				body +=	(response.issues[0].state ==99) ? '<option value="99" selected>Deleted</option>'    : '<option value="99">Deleted</option>';
				body +=	'</select>';
				body += '<div class="button-box">';
				body += '<button type="submit" class="submit-details-form">Submit</button>';
				body += '<button type="button" class="close-details-panel">Cancel</button>';
				body += '</div>';
				body += '</form>';
			return body;
		}
		$('main').addClass('issue-details-opened');
	    $('.action-panel').append(detailsTemplate()).slideToggle(200);
		$('.issue-details').attr('disabled', 'disabled');
		$('.loading-data').hide();
	})
	
	.fail(function(data) {
		
	    sweetAlert('Uh oh!','Unable to get issue details.','error');
	    $('.loading-data').hide();
	});
}

function postIssueDetails(url,api,type) {
		
    // Get the form.
    var form = $('.issue-details-form');
    
    $('.loading-data').css('display','inline');
    
    // Set up an event listener for the contact form.
	$(form).submit(function(event) {
		
	    // Stop the browser from submitting the form.
	    event.preventDefault();
	
	    // Serialize the form data.
		var formData = $(form).serialize();
		
		// Submit the form using AJAX.
		$.ajax({
		    type: 'POST',
		    url: $(form).attr('action'),
		    data: formData,
		    dataType: 'json'
		})
		
		.done(function(response) {
			
		    $('.action-panel').slideToggle(100).empty();
		    $('main').removeClass('issue-details-opened');
		    $('.issue-details').removeAttr('disabled');
		    getIssues(url,api,type);
		    $('.loading-data').hide();
		})
		
		.fail(function(data) {
			
		    sweetAlert('Uh oh!','Issue could not be updated.','error');
		    $('.loading-data').hide();
		});
	});
}

function getIssueComments(url,id,api) {
		
	$('.loading-data').css('display','inline');
	$('.action-panel').hide().empty();
	
	// Submit the form using AJAX.
	$.ajax({
	    type: 'GET',
	    url: url+'/api/issues/'+id+'.json?api_key='+api+'&comments=true',
	    dataType: 'json'
	})
	
	.done(function(response) {
		
		$('.comments-list').empty();
		
		function commentTemplate(i) {
			
			var body  =    '<div class="comment-box">';
				body +=    '<p>'+response.issues[0].comments[i].user.name+' said:</p><hr>';
				body +=	   '<span>'+response.issues[0].comments[i].comment+'</span>';
				body +=    '<p><small>'+$.format.prettyDate(response.issues[0].comments[i].created)+'</small></p>';
				body +=    '</div>';
			return body;
		}
		
		if ($(response.issues[0].comments).length != 0) {			
			$(response.issues[0].comments).each(function(c){
				$('.comments-list').append(commentTemplate(c));
			});
		} else {
			$('.comments-list').append('<p>No Comments Found</p>');
		}
		
		var header  = '<div class="button-box">';
			header += '<button type="button" class="close-comments-list button">Close Comments</button>';
			header += '<button type="button" class="add-comment button" data-issue-id="'+response.issues[0].id+'">Add Comment</button>';
			header += '<p class="text-center"><b>Comments for Issue #'+response.issues[0].id+'</b></p></div>';
			header += '</div>';
	
		$('.comments-list').slideToggle(200).prepend(header);
		$('main').hide();
		$('.loading-data').hide();
	})
	
	.fail(function(data) {
		
	    sweetAlert('Uh oh!','Unable to get issue comments.','error');
	    $('.loading-data').hide();
	});
}

function getAddComment(url,id,api) {
		
	$('.loading-data').css('display','inline');
	
	// Submit the form using AJAX.
	$.ajax({
	    type: 'GET',
	    url: url+'/api/issues/'+id+'.json?api_key='+api,
	    dataType: 'json'
	})
	
	.done(function(response) {
		
		function commentTemplate() {
			var body  = '<p><b>New comment for issue #'+response.issues[0].id+'</b></p>';
				body += '<form method="POST" class="issue-comment-form" action="'+url+'/api/issues/'+response.issues[0].id+'.json?api_key='+api+'" data-issues-id="'+response.issues[0].id+'">';
				body += '<input type="hidden" name="method" value="addcomment" id="issue-details-method">';
				body += '<textarea name="comment" placeholder="Add a comment..." id="issue-comment" rows="4"></textarea>';
				body += '<div class="text-center">';
				body += '<button type="submit" class="submit-comment-form button">Submit</button>';
				body += '<button type="button" class="close-comment-panel button">Cancel</button>';
				body += '</div>';
				body += '</form>';
			return body;
		}
		$('.comments-list').addClass('issue-comments-opened');
	    $('.action-panel').append(commentTemplate()).slideToggle(200);
	    $('.add-comment').attr('disabled', 'disabled');
		$('.loading-data').hide();
	})
	
	.fail(function(data) {
		
	    sweetAlert('Uh oh!','Unable to get issue details.','error');
	    $('.loading-data').hide();
	});
}

function postAddComment(url,api,type) {
		
    // Get the form.
    var form = $('.issue-comment-form');
    
    $('.loading-data').css('display','inline');
    
    // Set up an event listener for the contact form.
	$(form).submit(function(event) {
		
	    // Stop the browser from submitting the form.
	    event.preventDefault();
	
	    // Serialize the form data.
		var formData = $(form).serialize();
		
		// Submit the form using AJAX.
		$.ajax({
		    type: 'POST',
		    url: $(form).attr('action'),
		    data: formData,
		    dataType: 'json'
		})
		
		.done(function(response) {
			
		    $('.comments-list').removeClass('issue-comments-opened');
		    $('.add-comment').removeAttr('disabled');
		    getIssues(url,api,type);
		    refreshComments(url,$(form).data('issues-id'),api);
		    $('.action-panel').slideToggle(100).empty();
		    $('.loading-data').hide();
		})
		
		.fail(function(data) {
			
		    sweetAlert('Uh oh!','Comment could not be added.','error');
		    $('.loading-data').hide();
		});
	});
}

function refreshComments(url,id,api) {
		
	$('.loading-data').css('display','inline');
	
	// Submit the form using AJAX.
	$.ajax({
	    type: 'GET',
	    url: url+'/api/issues/'+id+'.json?api_key='+api+'&comments=true',
	    dataType: 'json'
	})
	
	.done(function(response) {
		
		$('.comments-list').empty();
		
		function commentTemplate(i) {
			var body  =    '<div class="comment-box">';
				body +=    '<p>'+response.issues[0].comments[i].user.name+' said:</p><hr>';
				body +=	   '<span>'+response.issues[0].comments[i].comment+'</span>';
				body +=    '<p><small>'+$.format.prettyDate(response.issues[0].comments[i].created)+'</small></p>';
				body +=    '</div>';
			return body;
		}
				
		$(response.issues[0].comments).each(function(c){
			$('.comments-list').append(commentTemplate(c));
		});
		
		var header  = '<div class="button-box">';
			header += '<button type="button" class="close-comments-list button">Close Comments</button>';
			header += '<button type="button" class="add-comment button" data-issue-id="'+response.issues[0].id+'">Add Comment</button>';
			header += '<p class="text-center"><b>Comments for Issue #'+response.issues[0].id+'</b></p></div>';
			header += '</div>';
			
		$('.comments-list').prepend(header);
		$('.loading-data').hide();
	})
	
	.fail(function(data) {
		
	    sweetAlert('Uh oh!','Unable to get issue comments.','error');
	    $('.loading-data').hide();
	});
}